==> symfony_5.4.4+dfsg.orig.tar.xz: symfony-5.4.4/src/Symfony/Component/Intl/Resources/data/languages/eu.php <==
<?php

return [
    'Names' => [
        'aa' => 'afarera',
        'ab' => 'abkhaziera',
        'ace' => 'acehnera',
        'ach' => 'acholiera',
        'ada' => 'adangmera',
        'ady' => 'adigera',
        'af' => 'afrikaans',
        'agq' => 'aghemera',
        'ain' => 'ainuera',
        'ak' => 'akanera',
        'ale' => 'aleutera',
        'alt' => 'hegoaldeko altaiera',
        'am' => 'amharera',
        'an' => 'aragoiera',
        'anp' => 'angikera',
        'ar' => 'arabiera',
        'arn' => 'maputxe',
        'arp' => 'arapaho',
        'as' => 'assamera',
        'asa' => 'asu',
        'ast' => 'asturiera',
        'av' => 'avarera',
        'awa' => 'awadhiera',
        'ay' => 'aimara',
        'az' => 'azerbaijanera',
        'ba' => 'baxkirera',
        'ban' => 'baliera',
        'bas' => 'basaa',
        'be' => 'bielorrusiera',
        'bem' => 'bembera',
        'bez' => 'benera',
        'bg' => 'bulgariera',
        'bho' => 'bhojpurera',
        'bi' => 'bislama',
        'bin' => 'edoera',
        'bla' => 'siksikera',
        'bm' => 'bambarera',
        'bn' => 'bengalera',
        'bo' => 'tibetera',
        'br' => 'bretoiera',
        'brx' => 'bodoera',
        'bs' => 'bosniera',
        'bug' => 'buginera',
        'byn' => 'bilena',
        'ca' => 'katalan',
        'ccp' => 'chakmera',
        'ce' => 'txetxenera',
        'ceb' => 'cebuanoera',
        'cgg' => 'chiga',
        'ch' => 'chamorrera',
        'chk' => 'chuukera',
        'chm' => 'mariera',
        'cho' => 'choctaw',
        'chr' => 'txerokiera',
        'chy' => 'cheyennera',
        'ckb' => 'erdialdeko kurduera',
        'co' => 'korsikera',
        'crs' => 'Seychelleetako kreolera',
        'cs' => 'txekiera',
        'cu' => 'elizako eslaviera',
        'cv' => 'txuvaxera',
        'cy' => 'gales',
        'da' => 'daniera',
        'dak' => 'dakotera',
        'dar' => 'dargvera',
        'dav' => 'taitera',
        'de' => 'aleman',
        'dgr' => 'dogribera',
        'dje' => 'zarma',
        'doi' => 'dogria',
        'dsb' => 'behe-sorabiera',
        'dua' => 'dualera',
        'dv' => 'divehiera',
        'dyo' => 'fonyi jolera',
        'dz' => 'dzongkha',
        'dzg' => 'dazaga',
        'ebu' => 'embuera',
        'ee' => 'eweera',
        'efi' => 'efikera',
        'eka' => 'akajuka',
        'el' => 'greziera',
        'en' => 'ingeles',
        'eo' => 'esperanto',
        'es' => 'espainiera',
        'et' => 'estoniera',
        'eu' => 'euskara',
        'ewo' => 'ewondera',
        'fa' => 'persiera',
        'ff' => 'fula',
        'fi' => 'finlandiera',
        'fil' => 'filipinera',
        'fj' => 'fijiera',
        'fo' => 'faroera',
        'fon' => 'fona',
        'fr' => 'frantses',
        'frc' => 'cajun frantsesa',
        'fur' => 'fruilera',
        'fy' => 'frisiera',
        'ga' => 'irlandera',
        'gaa' => 'ga',
        'gag' => 'gagauzera',
        'gd' => 'Eskoziako gaeliko',
        'gez' => 'ge’ez',
        'gil' => 'gilbertera',
        'gl' => 'galiziera',
        'gn' => 'guaraniera',
        'gor' => 'gorontaloa',
        'gsw' => 'Suitzako aleman',
        'gu' => 'gujaratera',
        'guz' => 'gusiiera',
        'gv' => 'manxera',
        'gwi' => 'gwichʼin',
        'ha' => 'hausa',
        'haw' => 'hawaiiera',
        'he' => 'hebreera',
        'hi' => 'hindi',
        'hil' => 'hiligainon',
        'hmn' => 'hmong',
        'hr' => 'kroaziera',
        'hsb' => 'goi-sorabiera',
        'ht' => 'Haitiko kreolera',
        'hu' => 'hungariera',
        'hup' => 'hupera',
        'hy' => 'armeniera',
        'hz' => 'hereroera',
        'ia' => 'interlingua',
        'iba' => 'ibanera',
        'ibb' => 'ibibioera',
        'id' => 'indonesiera',
        'ie' => 'interlingue',
        'ig' => 'igboera',
        'ii' => 'Sichuango yiera',
        'ilo' => 'ilokanera',
        'inh' => 'ingushera',
        'io' => 'ido',
        'is' => 'islandiera',
        'it' => 'italiera',
        'iu' => 'inuktitut',
        'ja' => 'japoniera',
        'jbo' => 'lojbanera',
        'jgo' => 'ngomba',
        'jmc' => 'machame',
        'jv' => 'javera',
        'ka' => 'georgiera',
        'kab' => 'kabilera',
        'kac' => 'jingpoera',
        'kaj' => 'kaiji',
        'kam' => 'kambera',
        'kbd' => 'kabardiera',
        'kcg' => 'kataba',
        'kde' => 'makondeera',
        'kea' => 'Cabo Verdeko kreolera',
        'kfo' => 'koroa',
        'kg' => 'kikongoa',
        'kgp' => 'kaingang',
        'kha' => 'kashia',
        'khq' => 'koyra chiini',
        'ki' => 'kikuyuera',
        'kj' => 'kuanyama',
        'kk' => 'kazakhera',
        'kkj' => 'kako',
        'kl' => 'groenlandiera',
        'kln' => 'kalenjinera',
        'km' => 'khemerera',
        'kmb' => 'kimbundua',
        'kn' => 'kannada',
        'ko' => 'koreera',
        'koi' => 'komi-permyakera',
        'kok' => 'konkanera',
        'kpe' => 'kpellea',
        'kr' => 'kanuriera',
        'krc' => 'karachayera-balkarera',
        'krl' => 'kareliera',
        'kru' => 'kurukhera',
        'ks' => 'kaxmirera',
        'ksb' => 'shambalera',
        'ksf' => 'bafiera',
        'ksh' => 'koloniera',
        'ku' => 'kurduera',
        'kum' => 'kumykera',
        'kv' => 'komiera',
        'kw' => 'kornubiera',
        'ky' => 'kirgizera',
        'la' => 'latin',
        'lad' => 'ladino',
        'lag' => 'langiera',
        'lb' => 'luxenburgera',
        'lez' => 'lezgiera',
        'lg' => 'luganda',
        'li' => 'limburgera',
        'lij' => 'liguriera',
        'lkt' => 'lakotera',
        'ln' => 'lingala',
        'lo' => 'laosera',
        'lou' => 'Louisianako kreolera',
        'loz' => 'loziera',
        'lrc' => 'iparraldeko lurera',
        'lt' => 'lituaniera',
        'lu' => 'Katangako lubera',
        'lua' => 'txilubera',
        'lun' => 'lundera',
        'luo' => 'luoera',
        'lus' => 'mizoa',
        'luy' => 'luhyera',
        'lv' => 'letoniera',
        'mad' => 'madurera',
        'mag' => 'magahiera',
        'mai' => 'maithilera',
        'mak' => 'makasarera',
        'mas' => 'masaiera',
        'mdf' => 'mokxera',
        'men' => 'mendeera',
        'mer' => 'meruera',
        'mfe' => 'Mauritaniako kreolera',
        'mg' => 'malgaxe',
        'mgh' => 'makhuwa-meettoera',
        'mgo' => 'metaʼera',
        'mh' => 'marshallera',
        'mi' => 'maoriera',
        'mic' => 'mikmakera',
        'min' => 'minangkabauera',
        'mk' => 'mazedoniera',
        'ml' => 'malabarera',
        'mn' => 'mongoliera',
        'mni' => 'manipurera',
        'moh' => 'mohawkera',
        'mos' => 'moreera',
        'mr' => 'marathera',
        'ms' => 'malaysiera',
        'mt' => 'maltera',
        'mua' => 'mudangera',
        'mus' => 'creera',
        'mwl' => 'mirandera',
        'my' => 'birmaniera',
        'myv' => 'erziera',
        'mzn' => 'mazandarandera',
        'na' => 'nauruera',
        'nap' => 'napoliera',
        'naq' => 'namera',
        'nb' => 'bokmål (norvegiera)',
        'nd' => 'iparraldeko ndebeleera',
        'nds' => 'behe-aleman',
        'ne' => 'nepalera',
        'new' => 'newarera',
        'ng' => 'ndongera',
        'nia' => 'niasera',
        'niu' => 'niueera',
        'nl' => 'nederlandera',
        'nmg' => 'kwasiera',
        'nn' => 'nynorsk (norvegiera)',
        'nnh' => 'ngiemboonera',
        'no' => 'norvegiera',
        'nog' => 'nogaiera',
        'nqo' => 'n’koera',
        'nr' => 'hegoaldeko ndebelera',
        'nso' => 'pediera',
        'nus' => 'nuerera',
        'nv' => 'navajoera',
        'ny' => 'chewera',
        'nyn' => 'ankolera',
        'oc' => 'okzitaniera',
        'om' => 'oromoera',
        'or' => 'oriya',
        'os' => 'osetiera',
        'pa' => 'punjabera',
        'pag' => 'pangasinanera',
        'pam' => 'pampangera',
        'pap' => 'papiamento',
        'pau' => 'palauera',
        'pcm' => 'Nigeriako pidgina',
        'pl' => 'poloniera',
        'prg' => 'prusiera',
        'ps' => 'paxtuera',
        'pt' => 'portuges',
        'qu' => 'kitxua',
        'quc' => 'quicheera',
        'rap' => 'rapa nui',
        'rar' => 'rarotongera',
        'rhg' => 'rohingyera',
        'rm' => 'erretorromaniera',
        'rn' => 'rundiera',
        'ro' => 'errumaniera',
        'rof' => 'rombo',
        'ru' => 'errusiera',
        'rup' => 'aromaniera',
        'rw' => 'kinyaruanda',
        'rwk' => 'rwera',
        'sa' => 'sanskrito',
        'sad' => 'sandaweera',
        'sah' => 'sakhera',
        'saq' => 'samburuera',
        'sat' => 'santalera',
        'sba' => 'ngambayera',
        'sbp' => 'sanguera',
        'sc' => 'sardiniera',
        'scn' => 'siziliera',
        'sco' => 'eskoziera',
        'sd' => 'sindhi',
        'se' => 'iparraldeko samiera',
        'seh' => 'senera',
        'ses' => 'koyraboro senni',
        'sg' => 'sango',
        'sh' => 'serbokroaziera',
        'shi' => 'tachelhit',
        'shn' => 'shanera',
        'si' => 'sinhala',
        'sk' => 'eslovakiera',
        'sl' => 'esloveniera',
        'sm' => 'samoera',
        'sma' => 'hegoaldeko samiera',
        'smj' => 'Luleko samiera',
        'smn' => 'Inariko samiera',
        'sms' => 'skolten samiera',
        'sn' => 'shonera',
        'snk' => 'soninkera',
        'so' => 'somaliera',
        'sq' => 'albaniera',
        'sr' => 'serbiera',
        'srn' => 'srananera',
        'ss' => 'swatiera',
        'ssy' => 'sahoa',
        'st' => 'hegoaldeko sothoera',
        'su' => 'sundanera',
        'suk' => 'sukumera',
        'sv' => 'suediera',
        'sw' => 'swahilia',
        'swb' => 'komoreera',
        'syr' => 'asiriera',
        'ta' => 'tamilera',
        'te' => 'telugu',
        'tem' => 'temnea',
        'teo' => 'tesoera',
        'tet' => 'tetum',
        'tg' => 'tajikera',
        'th' => 'thailandiera',
        'ti' => 'tigrinyera',
        'tig' => 'tigrea',
        'tk' => 'turkmenera',
        'tl' => 'tagaloa',
        'tlh' => 'klingonera',
        'tn' => 'tswanera',
        'to' => 'tongera',
        'tpi' => 'tok pisin',
        'tr' => 'turkiera',
        'trv' => 'tarokoa',
        'ts' => 'tsongera',
        'tt' => 'tatarera',
        'tum' => 'tumbukera',
        'tvl' => 'tuvaluera',
        'tw' => 'twia',
        'twq' => 'tasawaq',
        'ty' => 'tahitiera',
        'tyv' => 'tuvera',
        'tzm' => 'Erdialdeko Atlaseko amazigera',
        'udm' => 'udmurtera',
        'ug' => 'uigurrera',
        'uk' => 'ukrainera',
        'umb' => 'umbundu',
        'ur' => 'urdu',
        'uz' => 'uzbekera',
        'vai' => 'vaiera',
        've' => 'vendera',
        'vi' => 'vietnamera',
        'vo' => 'volapük',
        'vun' => 'vunjo',
        'wa' => 'waloiera',
        'wae' => 'walserera',
        'wal' => 'welayta',
        'war' => 'samerera',
        'wo' => 'wolofera',
        'xal' => 'kalmykera',
        'xh' => 'xhosera',
        'xog' => 'sogera',
        'yav' => 'yangbenera',
        'ybb' => 'yemba',
        'yi' => 'yiddish',
        'yo' => 'jorubera',
        'yue' => 'kantonera',
        'zgh' => 'amazigera estandarra',
        'zh' => 'txinera',
        'zu' => 'zuluera',
        'zun' => 'zuñia',
        'zza' => 'zazera',
    ],
    'LocalizedNames' => [
        'ar_001' => 'arabiera moderno estandarra',
        'de_AT' => 'Austriako aleman',
        'de_CH' => 'Suitzako aleman garai',
        'en_AU' => 'Australiako ingeles',
        'en_CA' => 'Kanadako ingeles',
        'en_GB' => 'Britania Handiko ingeles',
        'en_US' => 'AEBko ingeles',
        'es_419' => 'Latinoamerikako espainiera',
        'es_ES' => 'espainiera (Europa)',
        'es_MX' => 'Mexikoko espainiera',
        'fa_AF' => 'daria',
        'fr_CA' => 'Kanadako frantses',
        'fr_CH' => 'Suitzako frantses',
        'nds_NL' => 'behe-saxoiera',
        'nl_BE' => 'flandriera',
        'pt_BR' => 'Brasilgo portuges',
        'pt_PT' => 'Europako portuges',
        'ro_MD' => 'moldaviera',
        'sw_CD' => 'Kongoko swahilia',
        'zh_Hans' => 'txinera sinplifikatu',
        'zh_Hant' => 'txinera tradizionala',
    ],
];

==> symfony_5.4.23+dfsg.orig.tar.xz: symfony-5.4.23/src/Symfony/Component/Intl/Resources/data/languages/eu.php <==
<?php

return [
    'Names' => [
        'aa' => 'afarera',
        'ab' => 'abkhaziera',
        'ace' => 'acehnera',
        'ach' => 'acholiera',
        'ada' => 'adangmera',
        'ady' => 'adigera',
        'af' => 'afrikaansa',
        'agq' => 'aghemera',
        'ain' => 'ainuera',
        'ak' => 'akanera',
        'ale' => 'aleutera',
        'alt' => 'hegoaldeko altaiera',
        'am' => 'amharera',
        'an' => 'aragoiera',
        'ann' => 'oboloera',
        'anp' => 'angikera',
        'ar' => 'arabiera',
        'arn' => 'mapudunguna',
        'arp' => 'arapahoera',
        'ars' => 'Najdeko arabiera',
        'as' => 'assamera',
        'asa' => 'asua',
        'ast' => 'asturiera',
        'atj' => 'atikamekwera',
        'av' => 'avarera',
        'awa' => 'awadhiera',
        'ay' => 'aimara',
        'az' => 'azerbaijanera',
        'ba' => 'baxkirera',
        'ban' => 'baliera',
        'bas' => 'basaa',
        'be' => 'bielorrusiera',
        'bem' => 'bembera',
        'bez' => 'benera',
        'bg' => 'bulgariera',
        'bho' => 'bhojpurera',
        'bi' => 'bislama',
        'bin' => 'edoera',
        'bla' => 'siksikera',
        'bm' => 'bambarera',
        'bn' => 'bengalera',
        'bo' => 'tibetera',
        'br' => 'bretoiera',
        'brx' => 'bodoera',
        'bs' => 'bosniera',
        'bug' => 'buginera',
        'byn' => 'bilenera',
        'ca' => 'katalana',
        'cay' => 'cayugera',
        'ccp' => 'chakmera',
        'ce' => 'txetxenera',
        'ceb' => 'cebuanoera',
        'cgg' => 'chiga',
        'ch' => 'txamorroera',
        'chk' => 'chuukera',
        'chm' => 'mariera',
        'cho' => 'txoktawera',
        'chp' => 'chipewyera',
        'chr' => 'txerokiera',
        'chy' => 'txeienera',
        'ckb' => 'erdialdeko kurduera',
        'clc' => 'chilcotinera',
        'co' => 'korsikera',
        'crg' => 'metisera',
        'crj' => 'hego-ekialdeko creera',
        'crk' => 'lautadetako creera',
        'crl' => 'ipar-ekialdeko creera',
        'crm' => 'Mooseko creera',
        'crr' => 'Carolinako algonkinera',
        'crs' => 'Seychelleetako kreolera',
        'cs' => 'txekiera',
        'csw' => 'zingiretako creera',
        'cu' => 'elizako eslaviera',
        'cv' => 'txuvaxera',
        'cy' => 'galesa',
        'da' => 'daniera',
        'dak' => 'dakotera',
        'dar' => 'darginera',
        'dav' => 'taitera',
        'de' => 'alemana',
        'dgr' => 'dogribera',
        'dje' => 'zarma',
        'doi' => 'dogria',
        'dsb' => 'behe-sorabiera',
        'dua' => 'dualera',
        'dv' => 'dhivehia',
        'dyo' => 'fonyi jolera',
        'dz' => 'dzongkha',
        'dzg' => 'dazaera',
        'ebu' => 'embuera',
        'ee' => 'eweera',
        'efi' => 'efikera',
        'eka' => 'ekajuka',
        'el' => 'greziera',
        'en' => 'ingelesa',
        'eo' => 'esperantoa',
        'es' => 'espainiera',
        'et' => 'estoniera',
        'eu' => 'euskara',
        'ewo' => 'ewondoa',
        'fa' => 'persiera',
        'ff' => 'fula',
        'fi' => 'finlandiera',
        'fil' => 'filipinera',
        'fj' => 'fijiera',
        'fo' => 'faroera',
        'fon' => 'fonera',
        'fr' => 'frantsesa',
        'frc' => 'cajun frantsesa',
        'frr' => 'iparraldeko frisiera',
        'fur' => 'friulera',
        'fy' => 'frisiera',
        'ga' => 'irlandera',
        'gaa' => 'gaera',
        'gag' => 'gagauzera',
        'gd' => 'Eskoziako gaelikoa',
        'gez' => 'ge’eza',
        'gil' => 'kiribatiera',
        'gl' => 'galiziera',
        'gn' => 'guaraniera',
        'gor' => 'gorontaloera',
        'gsw' => 'Suitzako alemana',
        'gu' => 'gujaratera',
        'guz' => 'gusiiera',
        'gv' => 'manxera',
        'gwi' => 'gwich’inera',
        'ha' => 'hausa',
        'hai' => 'haidera',
        'haw' => 'hawaiiera',
        'hax' => 'hegoaldeko haidera',
        'he' => 'hebreera',
        'hi' => 'hindia',
        'hil' => 'hiligaynonera',
        'hmn' => 'hmonga',
        'hr' => 'kroaziera',
        'hsb' => 'goi-sorabiera',
        'ht' => 'Haitiko kreolera',
        'hu' => 'hungariera',
        'hup' => 'hupera',
        'hur' => 'halkomelema',
        'hy' => 'armeniera',
        'hz' => 'hereroera',
        'ia' => 'interlingua',
        'iba' => 'ibanera',
        'ibb' => 'ibibioera',
        'id' => 'indonesiera',
        'ie' => 'interlingue',
        'ig' => 'igboera',
        'ii' => 'Sichuango yiera',
        'ikt' => 'Kanada mendebaldeko inuitera',
        'ilo' => 'ilocanoera',
        'inh' => 'ingushera',
        'io' => 'idoa',
        'is' => 'islandiera',
        'it' => 'italiera',
        'iu' => 'inuitera',
        'ja' => 'japoniera',
        'jbo' => 'lojbana',
        'jgo' => 'ngomba',
        'jmc' => 'machamea',
        'jv' => 'javera',
        'ka' => 'georgiera',
        'kab' => 'kabiliera',
        'kac' => 'jingphoera',
        'kaj' => 'jjua',
        'kam' => 'kambera',
        'kbd' => 'kabardiera',
        'kcg' => 'tyapa',
        'kde' => 'makondeera',
        'kea' => 'Cabo Verdeko kreolera',
        'kfo' => 'koroa',
        'kg' => 'kikongoa',
        'kgp' => 'kaingangera',
        'kha' => 'khasiera',
        'khq' => 'koyra chiinia',
        'ki' => 'kikuyuera',
        'kj' => 'kuanyama',
        'kk' => 'kazakhera',
        'kkj' => 'kakoa',
        'kl' => 'groenlandiera',
        'kln' => 'kalenjinera',
        'km' => 'khemerera',
        'kmb' => 'kimbundua',
        'kn' => 'kannada',
        'ko' => 'koreera',
        'koi' => 'komi-permyakera',
        'kok' => 'konkanera',
        'kpe' => 'kpelleera',
        'kr' => 'kanuriera',
        'krc' => 'karachayera-balkarera',
        'krl' => 'kareliera',
        'kru' => 'kurukhera',
        'ks' => 'kaxmirera',
        'ksb' => 'shambalera',
        'ksf' => 'bafiera',
        'ksh' => 'koloniera',
        'ku' => 'kurduera',
        'kum' => 'kumykera',
        'kv' => 'komiera',
        'kw' => 'kornubiera',
        'kwk' => 'kwakwala',
        'ky' => 'kirgizera',
        'la' => 'latina',
        'lad' => 'ladinoa',
        'lag' => 'langiera',
        'lb' => 'luxenburgera',
        'lez' => 'lezginera',
        'lg' => 'luganda',
        'li' => 'limburgera',
        'lij' => 'liguriera',
        'lil' => 'lillooetera',
        'lkt' => 'lakotera',
        'ln' => 'lingala',
        'lo' => 'laosera',
        'lou' => 'Louisianako kreolera',
        'loz' => 'loziera',
        'lrc' => 'iparraldeko lurera',
        'lsm' => 'saamia',
        'lt' => 'lituaniera',
        'lu' => 'Katangako lubera',
        'lua' => 'Kasai mendebaldeko lubera',
        'lun' => 'lundera',
        'luo' => 'luoera',
        'lus' => 'mizoera',
        'luy' => 'luhyera',
        'lv' => 'letoniera',
        'mad' => 'madurera',
        'mag' => 'magadhera',
        'mai' => 'maithilia',
        'mak' => 'makassarera',
        'mas' => 'masaiera',
        'mdf' => 'mokxera',
        'men' => 'mendeera',
        'mer' => 'meruera',
        'mfe' => 'Mauritaniako kreolera',
        'mg' => 'malgaxea',
        'mgh' => 'makhuwa-meettoera',
        'mgo' => 'metaʼera',
        'mh' => 'marshallera',
        'mi' => 'maoriera',
        'mic' => 'mikmakera',
        'min' => 'minangkabauera',
        'mk' => 'mazedoniera',
        'ml' => 'malabarera',
        'mn' => 'mongoliera',
        'mni' => 'manipurera',
        'moe' => 'innuera',
        'moh' => 'mohawkera',
        'mos' => 'mossiera',
        'mr' => 'marathera',
        'ms' => 'malaysiera',
        'mt' => 'maltera',
        'mua' => 'mudangera',
        'mus' => 'muscogeera',
        'mwl' => 'mirandesa',
        'my' => 'birmaniera',
        'myv' => 'erziera',
        'mzn' => 'mazandarandera',
        'na' => 'nauruera',
        'nap' => 'napoliera',
        'naq' => 'namera',
        'nb' => 'bokmål (norvegiera)',
        'nd' => 'iparraldeko ndebeleera',
        'nds' => 'behe-alemana',
        'ne' => 'nepalera',
        'new' => 'newarera',
        'ng' => 'ndonga',
        'nia' => 'niasera',
        'niu' => 'niueera',
        'nl' => 'nederlandera',
        'nmg' => 'kwasiera',
        'nn' => 'nynorsk (norvegiera)',
        'nnh' => 'ngiemboonera',
        'no' => 'norvegiera',
        'nog' => 'nogaiera',
        'nqo' => 'n’koera',
        'nr' => 'hegoaldeko ndebelera',
        'nso' => 'pediera',
        'nus' => 'nuerera',
        'nv' => 'navajoera',
        'ny' => 'chewera',
        'nyn' => 'nkoreera',
        'oc' => 'okzitaniera',
        'ojb' => 'ipar-mendebaldeko ojibwa',
        'ojc' => 'erdialdeko ojibwa',
        'ojs' => 'oji-creera',
        'ojw' => 'mendebaldeko ojibwa',
        'oka' => 'okanaganera',
        'om' => 'oromoera',
        'or' => 'oriya',
        'os' => 'osetiera',
        'pa' => 'punjabera',
        'pag' => 'pangasinanera',
        'pam' => 'pampangera',
        'pap' => 'papiamentoa',
        'pau' => 'palauera',
        'pcm' => 'Nigeriako pidgina',
        'pis' => 'pijina',
        'pl' => 'poloniera',
        'pqm' => 'maliseet-passamaquoddyera',
        'prg' => 'prusiera',
        'ps' => 'paxtunera',
        'pt' => 'portugesa',
        'qu' => 'kitxua',
        'quc' => 'quicheera',
        'rap' => 'rapanuia',
        'rar' => 'rarotongera',
        'rhg' => 'rohingyera',
        'rm' => 'erretorromaniera',
        'rn' => 'rundiera',
        'ro' => 'errumaniera',
        'rof' => 'romboa',
        'ru' => 'errusiera',
        'rup' => 'aromaniera',
        'rw' => 'kinyaruanda',
        'rwk' => 'rwera',
        'sa' => 'sanskritoa',
        'sad' => 'sandaweera',
        'sah' => 'sakhera',
        'saq' => 'samburuera',
        'sat' => 'santalera',
        'sba' => 'ngambayera',
        'sbp' => 'sanguera',
        'sc' => 'sardiniera',
        'scn' => 'siziliera',
        'sco' => 'eskoziera',
        'sd' => 'sindhia',
        'se' => 'iparraldeko samiera',
        'seh' => 'senera',
        'ses' => 'koyraboro sennia',
        'sg' => 'sangoa',
        'sh' => 'serbokroaziera',
        'shi' => 'tachelhita',
        'shn' => 'shanera',
        'si' => 'sinhala',
        'sk' => 'eslovakiera',
        'sl' => 'esloveniera',
        'slh' => 'lushootseeda',
        'sm' => 'samoera',
        'sma' => 'hegoaldeko samiera',
        'smj' => 'Luleko samiera',
        'smn' => 'Inariko samiera',
        'sms' => 'skolten samiera',
        'sn' => 'shonera',
        'snk' => 'soninkera',
        'so' => 'somaliera',
        'sq' => 'albaniera',
        'sr' => 'serbiera',
        'srn' => 'srananera',
        'ss' => 'swatiera',
        'ssy' => 'sahoa',
        'st' => 'hegoaldeko sothoera',
        'str' => 'itsasarteetako salishera',
        'su' => 'sundanera',
        'suk' => 'sukumera',
        'sv' => 'suediera',
        'sw' => 'swahilia',
        'swb' => 'komoreera',
        'syr' => 'asiriera',
        'ta' => 'tamilera',
        'tce' => 'hegoaldeko tutchoneera',
        'te' => 'telugua',
        'tem' => 'temnea',
        'teo' => 'tesoera',
        'tet' => 'tetuma',
        'tg' => 'tajikera',
        'tgx' => 'tagishera',
        'th' => 'thailandiera',
        'tht' => 'tahltanera',
        'ti' => 'tigrinyera',
        'tig' => 'tigrea',
        'tk' => 'turkmenera',
        'tl' => 'tagaloa',
        'tlh' => 'klingonera',
        'tli' => 'tlingitera',
        'tn' => 'tswanera',
        'to' => 'tongera',
        'tok' => 'toki pona',
        'tpi' => 'tok pisin',
        'tr' => 'turkiera',
        'trv' => 'tarokoa',
        'ts' => 'tsongera',
        'tt' => 'tatarera',
        'ttm' => 'iparraldeko tutchoneera',
        'tum' => 'tumbukera',
        'tvl' => 'tuvaluera',
        'tw' => 'twia',
        'twq' => 'tasawaqa',
        'ty' => 'tahitiera',
        'tyv' => 'tuvera',
        'tzm' => 'Erdialdeko Atlaseko amazigera',
        'udm' => 'udmurtera',
        'ug' => 'uigurrera',
        'uk' => 'ukrainera',
        'umb' => 'umbundua',
        'ur' => 'urdua',
        'uz' => 'uzbekera',
        'vai' => 'vaiera',
        've' => 'vendera',
        'vec' => 'veneziera',
        'vi' => 'vietnamera',
        'vo' => 'volapük',
        'vun' => 'vunjoa',
        'wa' => 'waloiera',
        'wae' => 'walserera',
        'wal' => 'welayta',
        'war' => 'samerera',
        'wo' => 'wolofera',
        'wuu' => 'wu txinera',
        'xal' => 'kalmykera',
        'xh' => 'xhosera',
        'xog' => 'sogera',
        'yav' => 'yangbenera',
        'ybb' => 'yemba',
        'yi' => 'yiddisha',
        'yo' => 'jorubera',
        'yrl' => 'nheengatua',
        'yue' => 'kantonera',
        'zgh' => 'amazigera estandarra',
        'zh' => 'txinera',
        'zu' => 'zuluera',
        'zun' => 'zuñia',
        'zza' => 'zazera',
    ],
    'LocalizedNames' => [
        'ar_001' => 'arabiera moderno estandarra',
        'de_AT' => 'Austriako alemana',
        'de_CH' => 'Suitzako aleman garaia',
        'en_AU' => 'Australiako ingelesa',
        'en_CA' => 'Kanadako ingelesa',
        'en_GB' => 'Britainia Handiko ingelesa',
        'en_US' => 'ingeles amerikarra',
        'es_419' => 'Latinoamerikako espainiera',
        'es_ES' => 'espainiera (Europa)',
        'es_MX' => 'Mexikoko espainiera',
        'fa_AF' => 'daria',
        'fr_CA' => 'Kanadako frantsesa',
        'fr_CH' => 'Suitzako frantsesa',
        'nds_NL' => 'behe-saxoiera',
        'nl_BE' => 'flandriera',
        'pt_BR' => 'Brasilgo portugesa',
        'pt_PT' => 'Europako portugesa',
        'ro_MD' => 'moldaviera',
        'sw_CD' => 'Kongoko swahilia',
        'zh_Hans' => 'txinera sinplifikatua',
        'zh_Hant' => 'txinera tradizionala',
    ],
];
